@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Union
 
 from .literals import (
     ActionCategoryType,
@@ -26,6 +26,7 @@ from .literals import (
     JobStatusType,
     PipelineExecutionStatusType,
     StageExecutionStatusType,
+    StageTransitionTypeType,
     TriggerTypeType,
     WebhookAuthenticationTypeType,
 )
@@ -42,8 +43,10 @@ else:
 
 __all__ = (
     "AWSSessionCredentialsTypeDef",
-    "AcknowledgeJobOutputTypeDef",
-    "AcknowledgeThirdPartyJobOutputTypeDef",
+    "AcknowledgeJobInputTypeDef",
+    "AcknowledgeJobOutputResponseTypeDef",
+    "AcknowledgeThirdPartyJobInputTypeDef",
+    "AcknowledgeThirdPartyJobOutputResponseTypeDef",
     "ActionConfigurationPropertyTypeDef",
     "ActionConfigurationTypeDef",
     "ActionContextTypeDef",
@@ -74,34 +77,54 @@ __all__ = (
     "ArtifactStoreTypeDef",
     "ArtifactTypeDef",
     "BlockerDeclarationTypeDef",
-    "CreateCustomActionTypeOutputTypeDef",
-    "CreatePipelineOutputTypeDef",
+    "CreateCustomActionTypeInputTypeDef",
+    "CreateCustomActionTypeOutputResponseTypeDef",
+    "CreatePipelineInputTypeDef",
+    "CreatePipelineOutputResponseTypeDef",
     "CurrentRevisionTypeDef",
+    "DeleteCustomActionTypeInputTypeDef",
+    "DeletePipelineInputTypeDef",
+    "DeleteWebhookInputTypeDef",
+    "DeregisterWebhookWithThirdPartyInputTypeDef",
+    "DisableStageTransitionInputTypeDef",
+    "EnableStageTransitionInputTypeDef",
     "EncryptionKeyTypeDef",
     "ErrorDetailsTypeDef",
     "ExecutionDetailsTypeDef",
     "ExecutionTriggerTypeDef",
     "ExecutorConfigurationTypeDef",
     "FailureDetailsTypeDef",
-    "GetActionTypeOutputTypeDef",
-    "GetJobDetailsOutputTypeDef",
-    "GetPipelineExecutionOutputTypeDef",
-    "GetPipelineOutputTypeDef",
-    "GetPipelineStateOutputTypeDef",
-    "GetThirdPartyJobDetailsOutputTypeDef",
+    "GetActionTypeInputTypeDef",
+    "GetActionTypeOutputResponseTypeDef",
+    "GetJobDetailsInputTypeDef",
+    "GetJobDetailsOutputResponseTypeDef",
+    "GetPipelineExecutionInputTypeDef",
+    "GetPipelineExecutionOutputResponseTypeDef",
+    "GetPipelineInputTypeDef",
+    "GetPipelineOutputResponseTypeDef",
+    "GetPipelineStateInputTypeDef",
+    "GetPipelineStateOutputResponseTypeDef",
+    "GetThirdPartyJobDetailsInputTypeDef",
+    "GetThirdPartyJobDetailsOutputResponseTypeDef",
     "InputArtifactTypeDef",
     "JobDataTypeDef",
     "JobDetailsTypeDef",
     "JobTypeDef",
     "JobWorkerExecutorConfigurationTypeDef",
     "LambdaExecutorConfigurationTypeDef",
-    "ListActionExecutionsOutputTypeDef",
-    "ListActionTypesOutputTypeDef",
-    "ListPipelineExecutionsOutputTypeDef",
-    "ListPipelinesOutputTypeDef",
-    "ListTagsForResourceOutputTypeDef",
+    "ListActionExecutionsInputTypeDef",
+    "ListActionExecutionsOutputResponseTypeDef",
+    "ListActionTypesInputTypeDef",
+    "ListActionTypesOutputResponseTypeDef",
+    "ListPipelineExecutionsInputTypeDef",
+    "ListPipelineExecutionsOutputResponseTypeDef",
+    "ListPipelinesInputTypeDef",
+    "ListPipelinesOutputResponseTypeDef",
+    "ListTagsForResourceInputTypeDef",
+    "ListTagsForResourceOutputResponseTypeDef",
     "ListWebhookItemTypeDef",
-    "ListWebhooksOutputTypeDef",
+    "ListWebhooksInputTypeDef",
+    "ListWebhooksOutputResponseTypeDef",
     "OutputArtifactTypeDef",
     "PaginatorConfigTypeDef",
     "PipelineContextTypeDef",
@@ -110,13 +133,24 @@ __all__ = (
     "PipelineExecutionTypeDef",
     "PipelineMetadataTypeDef",
     "PipelineSummaryTypeDef",
-    "PollForJobsOutputTypeDef",
-    "PollForThirdPartyJobsOutputTypeDef",
-    "PutActionRevisionOutputTypeDef",
-    "PutApprovalResultOutputTypeDef",
-    "PutWebhookOutputTypeDef",
+    "PollForJobsInputTypeDef",
+    "PollForJobsOutputResponseTypeDef",
+    "PollForThirdPartyJobsInputTypeDef",
+    "PollForThirdPartyJobsOutputResponseTypeDef",
+    "PutActionRevisionInputTypeDef",
+    "PutActionRevisionOutputResponseTypeDef",
+    "PutApprovalResultInputTypeDef",
+    "PutApprovalResultOutputResponseTypeDef",
+    "PutJobFailureResultInputTypeDef",
+    "PutJobSuccessResultInputTypeDef",
+    "PutThirdPartyJobFailureResultInputTypeDef",
+    "PutThirdPartyJobSuccessResultInputTypeDef",
+    "PutWebhookInputTypeDef",
+    "PutWebhookOutputResponseTypeDef",
+    "RegisterWebhookWithThirdPartyInputTypeDef",
     "ResponseMetadataTypeDef",
-    "RetryStageExecutionOutputTypeDef",
+    "RetryStageExecutionInputTypeDef",
+    "RetryStageExecutionOutputResponseTypeDef",
     "S3ArtifactLocationTypeDef",
     "S3LocationTypeDef",
     "SourceRevisionTypeDef",
@@ -124,15 +158,21 @@ __all__ = (
     "StageDeclarationTypeDef",
     "StageExecutionTypeDef",
     "StageStateTypeDef",
-    "StartPipelineExecutionOutputTypeDef",
+    "StartPipelineExecutionInputTypeDef",
+    "StartPipelineExecutionOutputResponseTypeDef",
     "StopExecutionTriggerTypeDef",
-    "StopPipelineExecutionOutputTypeDef",
+    "StopPipelineExecutionInputTypeDef",
+    "StopPipelineExecutionOutputResponseTypeDef",
+    "TagResourceInputTypeDef",
     "TagTypeDef",
     "ThirdPartyJobDataTypeDef",
     "ThirdPartyJobDetailsTypeDef",
     "ThirdPartyJobTypeDef",
     "TransitionStateTypeDef",
-    "UpdatePipelineOutputTypeDef",
+    "UntagResourceInputTypeDef",
+    "UpdateActionTypeInputTypeDef",
+    "UpdatePipelineInputTypeDef",
+    "UpdatePipelineOutputResponseTypeDef",
     "WebhookAuthConfigurationTypeDef",
     "WebhookDefinitionTypeDef",
     "WebhookFilterRuleTypeDef",
@@ -147,16 +187,33 @@ AWSSessionCredentialsTypeDef = TypedDict(
     },
 )
 
-AcknowledgeJobOutputTypeDef = TypedDict(
-    "AcknowledgeJobOutputTypeDef",
+AcknowledgeJobInputTypeDef = TypedDict(
+    "AcknowledgeJobInputTypeDef",
+    {
+        "jobId": str,
+        "nonce": str,
+    },
+)
+
+AcknowledgeJobOutputResponseTypeDef = TypedDict(
+    "AcknowledgeJobOutputResponseTypeDef",
     {
         "status": JobStatusType,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-AcknowledgeThirdPartyJobOutputTypeDef = TypedDict(
-    "AcknowledgeThirdPartyJobOutputTypeDef",
+AcknowledgeThirdPartyJobInputTypeDef = TypedDict(
+    "AcknowledgeThirdPartyJobInputTypeDef",
+    {
+        "jobId": str,
+        "nonce": str,
+        "clientToken": str,
+    },
+)
+
+AcknowledgeThirdPartyJobOutputResponseTypeDef = TypedDict(
+    "AcknowledgeThirdPartyJobOutputResponseTypeDef",
     {
         "status": JobStatusType,
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -279,8 +336,8 @@ ActionExecutionOutputTypeDef = TypedDict(
         "outputArtifacts": List["ArtifactDetailTypeDef"],
         "executionResult": "ActionExecutionResultTypeDef",
         "outputVariables": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
+    total=False,
 )
 
 ActionExecutionResultTypeDef = TypedDict(
@@ -570,8 +627,35 @@ BlockerDeclarationTypeDef = TypedDict(
     },
 )
 
-CreateCustomActionTypeOutputTypeDef = TypedDict(
-    "CreateCustomActionTypeOutputTypeDef",
+_RequiredCreateCustomActionTypeInputTypeDef = TypedDict(
+    "_RequiredCreateCustomActionTypeInputTypeDef",
+    {
+        "category": ActionCategoryType,
+        "provider": str,
+        "version": str,
+        "inputArtifactDetails": "ArtifactDetailsTypeDef",
+        "outputArtifactDetails": "ArtifactDetailsTypeDef",
+    },
+)
+_OptionalCreateCustomActionTypeInputTypeDef = TypedDict(
+    "_OptionalCreateCustomActionTypeInputTypeDef",
+    {
+        "settings": "ActionTypeSettingsTypeDef",
+        "configurationProperties": List["ActionConfigurationPropertyTypeDef"],
+        "tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateCustomActionTypeInputTypeDef(
+    _RequiredCreateCustomActionTypeInputTypeDef, _OptionalCreateCustomActionTypeInputTypeDef
+):
+    pass
+
+
+CreateCustomActionTypeOutputResponseTypeDef = TypedDict(
+    "CreateCustomActionTypeOutputResponseTypeDef",
     {
         "actionType": "ActionTypeTypeDef",
         "tags": List["TagTypeDef"],
@@ -579,8 +663,29 @@ CreateCustomActionTypeOutputTypeDef = TypedDict(
     },
 )
 
-CreatePipelineOutputTypeDef = TypedDict(
-    "CreatePipelineOutputTypeDef",
+_RequiredCreatePipelineInputTypeDef = TypedDict(
+    "_RequiredCreatePipelineInputTypeDef",
+    {
+        "pipeline": "PipelineDeclarationTypeDef",
+    },
+)
+_OptionalCreatePipelineInputTypeDef = TypedDict(
+    "_OptionalCreatePipelineInputTypeDef",
+    {
+        "tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreatePipelineInputTypeDef(
+    _RequiredCreatePipelineInputTypeDef, _OptionalCreatePipelineInputTypeDef
+):
+    pass
+
+
+CreatePipelineOutputResponseTypeDef = TypedDict(
+    "CreatePipelineOutputResponseTypeDef",
     {
         "pipeline": "PipelineDeclarationTypeDef",
         "tags": List["TagTypeDef"],
@@ -598,7 +703,7 @@ _RequiredCurrentRevisionTypeDef = TypedDict(
 _OptionalCurrentRevisionTypeDef = TypedDict(
     "_OptionalCurrentRevisionTypeDef",
     {
-        "created": datetime,
+        "created": Union[datetime, str],
         "revisionSummary": str,
     },
     total=False,
@@ -609,6 +714,56 @@ class CurrentRevisionTypeDef(_RequiredCurrentRevisionTypeDef, _OptionalCurrentRe
     pass
 
 
+DeleteCustomActionTypeInputTypeDef = TypedDict(
+    "DeleteCustomActionTypeInputTypeDef",
+    {
+        "category": ActionCategoryType,
+        "provider": str,
+        "version": str,
+    },
+)
+
+DeletePipelineInputTypeDef = TypedDict(
+    "DeletePipelineInputTypeDef",
+    {
+        "name": str,
+    },
+)
+
+DeleteWebhookInputTypeDef = TypedDict(
+    "DeleteWebhookInputTypeDef",
+    {
+        "name": str,
+    },
+)
+
+DeregisterWebhookWithThirdPartyInputTypeDef = TypedDict(
+    "DeregisterWebhookWithThirdPartyInputTypeDef",
+    {
+        "webhookName": str,
+    },
+    total=False,
+)
+
+DisableStageTransitionInputTypeDef = TypedDict(
+    "DisableStageTransitionInputTypeDef",
+    {
+        "pipelineName": str,
+        "stageName": str,
+        "transitionType": StageTransitionTypeType,
+        "reason": str,
+    },
+)
+
+EnableStageTransitionInputTypeDef = TypedDict(
+    "EnableStageTransitionInputTypeDef",
+    {
+        "pipelineName": str,
+        "stageName": str,
+        "transitionType": StageTransitionTypeType,
+    },
+)
+
 EncryptionKeyTypeDef = TypedDict(
     "EncryptionKeyTypeDef",
     {
@@ -674,32 +829,76 @@ class FailureDetailsTypeDef(_RequiredFailureDetailsTypeDef, _OptionalFailureDeta
     pass
 
 
-GetActionTypeOutputTypeDef = TypedDict(
-    "GetActionTypeOutputTypeDef",
+GetActionTypeInputTypeDef = TypedDict(
+    "GetActionTypeInputTypeDef",
+    {
+        "category": ActionCategoryType,
+        "owner": str,
+        "provider": str,
+        "version": str,
+    },
+)
+
+GetActionTypeOutputResponseTypeDef = TypedDict(
+    "GetActionTypeOutputResponseTypeDef",
     {
         "actionType": "ActionTypeDeclarationTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetJobDetailsOutputTypeDef = TypedDict(
-    "GetJobDetailsOutputTypeDef",
+GetJobDetailsInputTypeDef = TypedDict(
+    "GetJobDetailsInputTypeDef",
+    {
+        "jobId": str,
+    },
+)
+
+GetJobDetailsOutputResponseTypeDef = TypedDict(
+    "GetJobDetailsOutputResponseTypeDef",
     {
         "jobDetails": "JobDetailsTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetPipelineExecutionOutputTypeDef = TypedDict(
-    "GetPipelineExecutionOutputTypeDef",
+GetPipelineExecutionInputTypeDef = TypedDict(
+    "GetPipelineExecutionInputTypeDef",
+    {
+        "pipelineName": str,
+        "pipelineExecutionId": str,
+    },
+)
+
+GetPipelineExecutionOutputResponseTypeDef = TypedDict(
+    "GetPipelineExecutionOutputResponseTypeDef",
     {
         "pipelineExecution": "PipelineExecutionTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetPipelineOutputTypeDef = TypedDict(
-    "GetPipelineOutputTypeDef",
+_RequiredGetPipelineInputTypeDef = TypedDict(
+    "_RequiredGetPipelineInputTypeDef",
+    {
+        "name": str,
+    },
+)
+_OptionalGetPipelineInputTypeDef = TypedDict(
+    "_OptionalGetPipelineInputTypeDef",
+    {
+        "version": int,
+    },
+    total=False,
+)
+
+
+class GetPipelineInputTypeDef(_RequiredGetPipelineInputTypeDef, _OptionalGetPipelineInputTypeDef):
+    pass
+
+
+GetPipelineOutputResponseTypeDef = TypedDict(
+    "GetPipelineOutputResponseTypeDef",
     {
         "pipeline": "PipelineDeclarationTypeDef",
         "metadata": "PipelineMetadataTypeDef",
@@ -707,8 +906,15 @@ GetPipelineOutputTypeDef = TypedDict(
     },
 )
 
-GetPipelineStateOutputTypeDef = TypedDict(
-    "GetPipelineStateOutputTypeDef",
+GetPipelineStateInputTypeDef = TypedDict(
+    "GetPipelineStateInputTypeDef",
+    {
+        "name": str,
+    },
+)
+
+GetPipelineStateOutputResponseTypeDef = TypedDict(
+    "GetPipelineStateOutputResponseTypeDef",
     {
         "pipelineName": str,
         "pipelineVersion": int,
@@ -719,8 +925,16 @@ GetPipelineStateOutputTypeDef = TypedDict(
     },
 )
 
-GetThirdPartyJobDetailsOutputTypeDef = TypedDict(
-    "GetThirdPartyJobDetailsOutputTypeDef",
+GetThirdPartyJobDetailsInputTypeDef = TypedDict(
+    "GetThirdPartyJobDetailsInputTypeDef",
+    {
+        "jobId": str,
+        "clientToken": str,
+    },
+)
+
+GetThirdPartyJobDetailsOutputResponseTypeDef = TypedDict(
+    "GetThirdPartyJobDetailsOutputResponseTypeDef",
     {
         "jobDetails": "ThirdPartyJobDetailsTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -786,8 +1000,31 @@ LambdaExecutorConfigurationTypeDef = TypedDict(
     },
 )
 
-ListActionExecutionsOutputTypeDef = TypedDict(
-    "ListActionExecutionsOutputTypeDef",
+_RequiredListActionExecutionsInputTypeDef = TypedDict(
+    "_RequiredListActionExecutionsInputTypeDef",
+    {
+        "pipelineName": str,
+    },
+)
+_OptionalListActionExecutionsInputTypeDef = TypedDict(
+    "_OptionalListActionExecutionsInputTypeDef",
+    {
+        "filter": "ActionExecutionFilterTypeDef",
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListActionExecutionsInputTypeDef(
+    _RequiredListActionExecutionsInputTypeDef, _OptionalListActionExecutionsInputTypeDef
+):
+    pass
+
+
+ListActionExecutionsOutputResponseTypeDef = TypedDict(
+    "ListActionExecutionsOutputResponseTypeDef",
     {
         "actionExecutionDetails": List["ActionExecutionDetailTypeDef"],
         "nextToken": str,
@@ -795,8 +1032,18 @@ ListActionExecutionsOutputTypeDef = TypedDict(
     },
 )
 
-ListActionTypesOutputTypeDef = TypedDict(
-    "ListActionTypesOutputTypeDef",
+ListActionTypesInputTypeDef = TypedDict(
+    "ListActionTypesInputTypeDef",
+    {
+        "actionOwnerFilter": ActionOwnerType,
+        "nextToken": str,
+        "regionFilter": str,
+    },
+    total=False,
+)
+
+ListActionTypesOutputResponseTypeDef = TypedDict(
+    "ListActionTypesOutputResponseTypeDef",
     {
         "actionTypes": List["ActionTypeTypeDef"],
         "nextToken": str,
@@ -804,8 +1051,30 @@ ListActionTypesOutputTypeDef = TypedDict(
     },
 )
 
-ListPipelineExecutionsOutputTypeDef = TypedDict(
-    "ListPipelineExecutionsOutputTypeDef",
+_RequiredListPipelineExecutionsInputTypeDef = TypedDict(
+    "_RequiredListPipelineExecutionsInputTypeDef",
+    {
+        "pipelineName": str,
+    },
+)
+_OptionalListPipelineExecutionsInputTypeDef = TypedDict(
+    "_OptionalListPipelineExecutionsInputTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListPipelineExecutionsInputTypeDef(
+    _RequiredListPipelineExecutionsInputTypeDef, _OptionalListPipelineExecutionsInputTypeDef
+):
+    pass
+
+
+ListPipelineExecutionsOutputResponseTypeDef = TypedDict(
+    "ListPipelineExecutionsOutputResponseTypeDef",
     {
         "pipelineExecutionSummaries": List["PipelineExecutionSummaryTypeDef"],
         "nextToken": str,
@@ -813,8 +1082,17 @@ ListPipelineExecutionsOutputTypeDef = TypedDict(
     },
 )
 
-ListPipelinesOutputTypeDef = TypedDict(
-    "ListPipelinesOutputTypeDef",
+ListPipelinesInputTypeDef = TypedDict(
+    "ListPipelinesInputTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
+ListPipelinesOutputResponseTypeDef = TypedDict(
+    "ListPipelinesOutputResponseTypeDef",
     {
         "pipelines": List["PipelineSummaryTypeDef"],
         "nextToken": str,
@@ -822,8 +1100,30 @@ ListPipelinesOutputTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceOutputTypeDef = TypedDict(
-    "ListTagsForResourceOutputTypeDef",
+_RequiredListTagsForResourceInputTypeDef = TypedDict(
+    "_RequiredListTagsForResourceInputTypeDef",
+    {
+        "resourceArn": str,
+    },
+)
+_OptionalListTagsForResourceInputTypeDef = TypedDict(
+    "_OptionalListTagsForResourceInputTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
+
+class ListTagsForResourceInputTypeDef(
+    _RequiredListTagsForResourceInputTypeDef, _OptionalListTagsForResourceInputTypeDef
+):
+    pass
+
+
+ListTagsForResourceOutputResponseTypeDef = TypedDict(
+    "ListTagsForResourceOutputResponseTypeDef",
     {
         "tags": List["TagTypeDef"],
         "nextToken": str,
@@ -855,8 +1155,17 @@ class ListWebhookItemTypeDef(_RequiredListWebhookItemTypeDef, _OptionalListWebho
     pass
 
 
-ListWebhooksOutputTypeDef = TypedDict(
-    "ListWebhooksOutputTypeDef",
+ListWebhooksInputTypeDef = TypedDict(
+    "ListWebhooksInputTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+ListWebhooksOutputResponseTypeDef = TypedDict(
+    "ListWebhooksOutputResponseTypeDef",
     {
         "webhooks": List["ListWebhookItemTypeDef"],
         "NextToken": str,
@@ -966,24 +1275,75 @@ PipelineSummaryTypeDef = TypedDict(
     total=False,
 )
 
-PollForJobsOutputTypeDef = TypedDict(
-    "PollForJobsOutputTypeDef",
+_RequiredPollForJobsInputTypeDef = TypedDict(
+    "_RequiredPollForJobsInputTypeDef",
+    {
+        "actionTypeId": "ActionTypeIdTypeDef",
+    },
+)
+_OptionalPollForJobsInputTypeDef = TypedDict(
+    "_OptionalPollForJobsInputTypeDef",
+    {
+        "maxBatchSize": int,
+        "queryParam": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class PollForJobsInputTypeDef(_RequiredPollForJobsInputTypeDef, _OptionalPollForJobsInputTypeDef):
+    pass
+
+
+PollForJobsOutputResponseTypeDef = TypedDict(
+    "PollForJobsOutputResponseTypeDef",
     {
         "jobs": List["JobTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-PollForThirdPartyJobsOutputTypeDef = TypedDict(
-    "PollForThirdPartyJobsOutputTypeDef",
+_RequiredPollForThirdPartyJobsInputTypeDef = TypedDict(
+    "_RequiredPollForThirdPartyJobsInputTypeDef",
+    {
+        "actionTypeId": "ActionTypeIdTypeDef",
+    },
+)
+_OptionalPollForThirdPartyJobsInputTypeDef = TypedDict(
+    "_OptionalPollForThirdPartyJobsInputTypeDef",
+    {
+        "maxBatchSize": int,
+    },
+    total=False,
+)
+
+
+class PollForThirdPartyJobsInputTypeDef(
+    _RequiredPollForThirdPartyJobsInputTypeDef, _OptionalPollForThirdPartyJobsInputTypeDef
+):
+    pass
+
+
+PollForThirdPartyJobsOutputResponseTypeDef = TypedDict(
+    "PollForThirdPartyJobsOutputResponseTypeDef",
     {
         "jobs": List["ThirdPartyJobTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-PutActionRevisionOutputTypeDef = TypedDict(
-    "PutActionRevisionOutputTypeDef",
+PutActionRevisionInputTypeDef = TypedDict(
+    "PutActionRevisionInputTypeDef",
+    {
+        "pipelineName": str,
+        "stageName": str,
+        "actionName": str,
+        "actionRevision": "ActionRevisionTypeDef",
+    },
+)
+
+PutActionRevisionOutputResponseTypeDef = TypedDict(
+    "PutActionRevisionOutputResponseTypeDef",
     {
         "newRevision": bool,
         "pipelineExecutionId": str,
@@ -991,22 +1351,126 @@ PutActionRevisionOutputTypeDef = TypedDict(
     },
 )
 
-PutApprovalResultOutputTypeDef = TypedDict(
-    "PutApprovalResultOutputTypeDef",
+PutApprovalResultInputTypeDef = TypedDict(
+    "PutApprovalResultInputTypeDef",
+    {
+        "pipelineName": str,
+        "stageName": str,
+        "actionName": str,
+        "result": "ApprovalResultTypeDef",
+        "token": str,
+    },
+)
+
+PutApprovalResultOutputResponseTypeDef = TypedDict(
+    "PutApprovalResultOutputResponseTypeDef",
     {
         "approvedAt": datetime,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-PutWebhookOutputTypeDef = TypedDict(
-    "PutWebhookOutputTypeDef",
+PutJobFailureResultInputTypeDef = TypedDict(
+    "PutJobFailureResultInputTypeDef",
+    {
+        "jobId": str,
+        "failureDetails": "FailureDetailsTypeDef",
+    },
+)
+
+_RequiredPutJobSuccessResultInputTypeDef = TypedDict(
+    "_RequiredPutJobSuccessResultInputTypeDef",
+    {
+        "jobId": str,
+    },
+)
+_OptionalPutJobSuccessResultInputTypeDef = TypedDict(
+    "_OptionalPutJobSuccessResultInputTypeDef",
+    {
+        "currentRevision": "CurrentRevisionTypeDef",
+        "continuationToken": str,
+        "executionDetails": "ExecutionDetailsTypeDef",
+        "outputVariables": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class PutJobSuccessResultInputTypeDef(
+    _RequiredPutJobSuccessResultInputTypeDef, _OptionalPutJobSuccessResultInputTypeDef
+):
+    pass
+
+
+PutThirdPartyJobFailureResultInputTypeDef = TypedDict(
+    "PutThirdPartyJobFailureResultInputTypeDef",
+    {
+        "jobId": str,
+        "clientToken": str,
+        "failureDetails": "FailureDetailsTypeDef",
+    },
+)
+
+_RequiredPutThirdPartyJobSuccessResultInputTypeDef = TypedDict(
+    "_RequiredPutThirdPartyJobSuccessResultInputTypeDef",
+    {
+        "jobId": str,
+        "clientToken": str,
+    },
+)
+_OptionalPutThirdPartyJobSuccessResultInputTypeDef = TypedDict(
+    "_OptionalPutThirdPartyJobSuccessResultInputTypeDef",
+    {
+        "currentRevision": "CurrentRevisionTypeDef",
+        "continuationToken": str,
+        "executionDetails": "ExecutionDetailsTypeDef",
+    },
+    total=False,
+)
+
+
+class PutThirdPartyJobSuccessResultInputTypeDef(
+    _RequiredPutThirdPartyJobSuccessResultInputTypeDef,
+    _OptionalPutThirdPartyJobSuccessResultInputTypeDef,
+):
+    pass
+
+
+_RequiredPutWebhookInputTypeDef = TypedDict(
+    "_RequiredPutWebhookInputTypeDef",
+    {
+        "webhook": "WebhookDefinitionTypeDef",
+    },
+)
+_OptionalPutWebhookInputTypeDef = TypedDict(
+    "_OptionalPutWebhookInputTypeDef",
+    {
+        "tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class PutWebhookInputTypeDef(_RequiredPutWebhookInputTypeDef, _OptionalPutWebhookInputTypeDef):
+    pass
+
+
+PutWebhookOutputResponseTypeDef = TypedDict(
+    "PutWebhookOutputResponseTypeDef",
     {
         "webhook": "ListWebhookItemTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
+RegisterWebhookWithThirdPartyInputTypeDef = TypedDict(
+    "RegisterWebhookWithThirdPartyInputTypeDef",
+    {
+        "webhookName": str,
+    },
+    total=False,
+)
+
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
     {
@@ -1018,8 +1482,18 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-RetryStageExecutionOutputTypeDef = TypedDict(
-    "RetryStageExecutionOutputTypeDef",
+RetryStageExecutionInputTypeDef = TypedDict(
+    "RetryStageExecutionInputTypeDef",
+    {
+        "pipelineName": str,
+        "stageName": str,
+        "pipelineExecutionId": str,
+        "retryMode": Literal["FAILED_ACTIONS"],
+    },
+)
+
+RetryStageExecutionOutputResponseTypeDef = TypedDict(
+    "RetryStageExecutionOutputResponseTypeDef",
     {
         "pipelineExecutionId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -1112,8 +1586,29 @@ StageStateTypeDef = TypedDict(
     total=False,
 )
 
-StartPipelineExecutionOutputTypeDef = TypedDict(
-    "StartPipelineExecutionOutputTypeDef",
+_RequiredStartPipelineExecutionInputTypeDef = TypedDict(
+    "_RequiredStartPipelineExecutionInputTypeDef",
+    {
+        "name": str,
+    },
+)
+_OptionalStartPipelineExecutionInputTypeDef = TypedDict(
+    "_OptionalStartPipelineExecutionInputTypeDef",
+    {
+        "clientRequestToken": str,
+    },
+    total=False,
+)
+
+
+class StartPipelineExecutionInputTypeDef(
+    _RequiredStartPipelineExecutionInputTypeDef, _OptionalStartPipelineExecutionInputTypeDef
+):
+    pass
+
+
+StartPipelineExecutionOutputResponseTypeDef = TypedDict(
+    "StartPipelineExecutionOutputResponseTypeDef",
     {
         "pipelineExecutionId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -1128,14 +1623,45 @@ StopExecutionTriggerTypeDef = TypedDict(
     total=False,
 )
 
-StopPipelineExecutionOutputTypeDef = TypedDict(
-    "StopPipelineExecutionOutputTypeDef",
+_RequiredStopPipelineExecutionInputTypeDef = TypedDict(
+    "_RequiredStopPipelineExecutionInputTypeDef",
+    {
+        "pipelineName": str,
+        "pipelineExecutionId": str,
+    },
+)
+_OptionalStopPipelineExecutionInputTypeDef = TypedDict(
+    "_OptionalStopPipelineExecutionInputTypeDef",
+    {
+        "abandon": bool,
+        "reason": str,
+    },
+    total=False,
+)
+
+
+class StopPipelineExecutionInputTypeDef(
+    _RequiredStopPipelineExecutionInputTypeDef, _OptionalStopPipelineExecutionInputTypeDef
+):
+    pass
+
+
+StopPipelineExecutionOutputResponseTypeDef = TypedDict(
+    "StopPipelineExecutionOutputResponseTypeDef",
     {
         "pipelineExecutionId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
+TagResourceInputTypeDef = TypedDict(
+    "TagResourceInputTypeDef",
+    {
+        "resourceArn": str,
+        "tags": List["TagTypeDef"],
+    },
+)
+
 TagTypeDef = TypedDict(
     "TagTypeDef",
     {
@@ -1189,8 +1715,30 @@ TransitionStateTypeDef = TypedDict(
     total=False,
 )
 
-UpdatePipelineOutputTypeDef = TypedDict(
-    "UpdatePipelineOutputTypeDef",
+UntagResourceInputTypeDef = TypedDict(
+    "UntagResourceInputTypeDef",
+    {
+        "resourceArn": str,
+        "tagKeys": List[str],
+    },
+)
+
+UpdateActionTypeInputTypeDef = TypedDict(
+    "UpdateActionTypeInputTypeDef",
+    {
+        "actionType": "ActionTypeDeclarationTypeDef",
+    },
+)
+
+UpdatePipelineInputTypeDef = TypedDict(
+    "UpdatePipelineInputTypeDef",
+    {
+        "pipeline": "PipelineDeclarationTypeDef",
+    },
+)
+
+UpdatePipelineOutputResponseTypeDef = TypedDict(
+    "UpdatePipelineOutputResponseTypeDef",
     {
         "pipeline": "PipelineDeclarationTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
